from pathlib import Path
from typing import Generator

def find_files_w_extension(folder_path:str, extension:str, search_subdir:bool=False) -> Generator[Path, None, None]:
    "Returns a list of files in the directory with matching extension"
    return Path(folder_path).glob(f"{'**/' if search_subdir else ''}*.{extension}")


from ak_file.search import *
from pathlib import Path

parent_dir = Path(__file__).parent.parent

def test_find_files_w_extension():
    assert len(list(find_files_w_extension(parent_dir, 'py', False))) == 0
    assert len(list(find_files_w_extension(parent_dir, 'toml', False))) == 1